@@ -3,7 +3,6 @@ import multiprocessing
 import threading
 from typing import Literal, Optional
 
-from scaled.scheduler.worker_manager.vanilla import AllocatorType
 from scaled.utility.event_loop import register_event_loop
 from scaled.utility.zmq_config import ZMQConfig
 from scaled.scheduler.main import Scheduler
@@ -17,7 +16,7 @@ class SchedulerProcess(multiprocessing.get_context("spawn").Process):
         stop_event: threading.Event,
         per_worker_queue_size: int,
         worker_timeout_seconds: int,
-        function_timeout_seconds: int,
+        function_retention_seconds: int,
         event_loop: Literal["builtin", "uvloop"] = "builtin",
     ):
         multiprocessing.Process.__init__(self, name="Scheduler")
@@ -25,7 +24,7 @@ class SchedulerProcess(multiprocessing.get_context("spawn").Process):
         self._stop_event = stop_event
         self._per_worker_queue_size = per_worker_queue_size
         self._worker_timeout_seconds = worker_timeout_seconds
-        self._function_timeout_seconds = function_timeout_seconds
+        self._function_retention_seconds = function_retention_seconds
         self._scheduler: Optional[Scheduler] = None
         self._event_loop = event_loop
 
@@ -37,7 +36,7 @@ class SchedulerProcess(multiprocessing.get_context("spawn").Process):
             stop_event=self._stop_event,
             per_worker_queue_size=self._per_worker_queue_size,
             worker_timeout_seconds=self._worker_timeout_seconds,
-            function_timeout_seconds=self._function_timeout_seconds,
+            function_retention_seconds=self._function_retention_seconds,
         )
 
         register_event_loop(self._event_loop)
